@@ -12,7 +12,7 @@ list=`awk '$4~"[0-9]$"{print $4}' /proc/partitions | grep -v "mmcblk*" | grep -v
 for partitions in $list
 	do
 		mkdir -p /media/$partitions
-		mount /dev/$partitions /media/$partitions
+		mount -o rw,noauto,nodev,noexec,nosuid,noatime,nodiratime,utf8,uid=29999,shortname=mixed,dmask=000,fmask=0133,rodir /dev/$partitions /media/$partitions
 done
 }
 
