@@ -6,16 +6,18 @@ KernelMessagesWindow::KernelMessagesWindow(QWidget *parent) :
     ui(new Ui::KernelMessagesWindow)
 {
     ui->setupUi(this);
+    setAttribute(Qt::WA_DeleteOnClose);
     connect(ui->actionExport, SIGNAL(triggered()), this, SLOT(exportlogs()));
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
+    QMainWindow::setCentralWidget(ui->textBrowser);
 }
 
 KernelMessagesWindow::~KernelMessagesWindow()
 {
     delete ui;
-    system("rm /home/user/.tempdmesg");
+    system("rm /home/user/.tempdmesg 2> /dev/null");
 }
 
 void KernelMessagesWindow::showLogs()
